#include <stdio.h>
#include <stdlib.h>
#include "complex.h"
/***********************************************************
* FUNCTION NAME: assign
*
* DESCRIPTION:  assigns to complex number pointed to by a
*               the complex number pointed to by b
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     a        O  left hand side of assignment
* ComplexT*     b        I  rhs of assignment
* RETURN VALUE: void
*
* CHANGES: complex pointed to by a
*************************************************************/
void assign(ComplexT *a, const ComplexT *b)
/* parameters passed as pointers */
{
    a->re = b->re;
    a->im = b->im;
}
/***********************************************************
* FUNCTION NAME: add
*
* DESCRIPTION:  adds two complex numbers
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     a        I  pointer to first term
* ComplexT*     b        I  pointer to 2nd term
* ComplexT*     c        O  pointer to sum
* RETURN VALUE: void
*
* CHANGES: sum pointed to by c
*************************************************************/
void add(const ComplexT *a, const ComplexT *b, ComplexT *c)
/* parameters passes as pointers */
{
    c->re=a->re+b->re;
    c->im=a->im+b->im;
};
/***********************************************************
* FUNCTION NAME: subtract
*
* DESCRIPTION:  subtracts two complex numbers
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     a        I  pointer to subtrahend
* ComplexT*     b        I  pointer to subtractor
* ComplexT*     c        O  pointer to difference
* RETURN VALUE: void
*
* CHANGES: difference pointed to by c
*************************************************************/
void subtract(const ComplexT *a, const ComplexT *b, ComplexT *c)
/* parameters passed as pointers */
{
    c->re=a->re-b->re;
    c->im=a->im-b->im;
}
/***********************************************************
* FUNCTION NAME: multiply
*
* DESCRIPTION:  multiplies two complex numbers
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     a        I  pointer to multiplicand
* ComplexT*     b        I  pointer to multiplier
* ComplexT*     c        O  pointer to product
* RETURN VALUE: void
*
* CHANGES: product pointed to by c
*************************************************************/
void multiply(const ComplexT *a, const ComplexT *b, ComplexT *c)
/* parameters passed as pointers */
{
    c->re=a->re*b->re-a->im*b->im;
    c->im=a->im*b->re+a->re*b->im;
}

/***********************************************************
* FUNCTION NAME: divide
*
* DESCRIPTION:  divides two complex numbers
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     a        I  pointer to dividend
* ComplexT*     b        I  pointer to divisor
* ComplexT*     c        O  pointer to quotient
* RETURN VALUE: void
*
* CHANGES: quotient pointed to by c
*************************************************************/
void divide(const ComplexT *a, const ComplexT *b, ComplexT *c)
/* parameters passed as pointers */
{
    float x;

    x=b->re*b->re+b->im*b->im;
    if (x==0)
    {
        printf("\nDivision by zero!\n");
        exit(1);
    }
    else
    {
        c->re=(a->re*b->re+a->im*b->im)/x;
        c->im=(a->im*b->re-a->re*b->im)/x;
    }
}
// end of complex.c
