#include <stdlib.h>
#include <stdio.h>
#include "complexPoly.h"
/***********************************************************
* FUNCTION NAME: printPoly
*
* DESCRIPTION:  prints a polynomial
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT*     p        I  pointer to array of coefficients
* int           n        n  degree of polynomial
* RETURN VALUE: void
*
* CHANGES: -
*************************************************************/
void printPoly(const ComplexT *p, int n)
{
    while (n >= 0 )
    {
        if (n > 1)
            printf("(%f + %fi)*x^%d + ", (p + n)->re, (p + n)->im, n);
        else
        {
            if (n > 0)
                printf("(%f + %fi)*x + ", (p + n)->re, (p + n)->im);
            else
                printf("(%f + %fi)", (p + n)->re, (p + n)->im);
        }
        n--;
    }
    printf("\n");
}

/***********************************************************
* FUNCTION NAME: Horner
*
* DESCRIPTION:  evaluates polynomial a given as an array of
*               coefficients using horner's scheme, on point x
*
* ARGUMENT LIST:
* Argument        Type   IO      Description
* ------------- -------- -- --------------------------------
* ComplexT      a[]      I  array of coefficients
* int           n        I  degree of polynomial
* ComplexT*     x        I  point of evaluation
* RETURN VALUE: ComplexT*
*
* CHANGES: -
*************************************************************/
ComplexT *Horner( ComplexT a[], int n, ComplexT *x)
{
    int i;
    // alocate space for result of evaluation
    ComplexT *result = (ComplexT *)malloc(sizeof(ComplexT));

    if (!result) return NULL;
    assign(result, a + n);
    for (i = n - 1; i >= 0 ; --i)
    {
        multiply(result, x, result);
        add(result, a + i, result);
    }
    return result;
}
